@@ -112,6 +112,9 @@ class PikaProducer(EventChannel):
     def _close(self):
         self.connection.close()
 
+    def is_connected(self):
+        return True
+
 
 class FileProducer(EventChannel):
     """Log events to a file in json format.
@@ -156,6 +159,9 @@ class FileProducer(EventChannel):
         self.event_logger.info(json.dumps(event))
         self.event_logger.handlers[0].flush()
 
+    def is_connected(self):
+        return True
+
 
 class KafkaProducer(EventChannel):
     def __init__(
@@ -172,7 +178,6 @@ class KafkaProducer(EventChannel):
         loglevel=logging.ERROR,
     ):
 
-        self.producer = None
         self.host = host
         self.topic = topic
         self.security_protocol = security_protocol
@@ -182,7 +187,7 @@ class KafkaProducer(EventChannel):
         self.ssl_certfile = ssl_certfile
         self.ssl_keyfile = ssl_keyfile
         self.ssl_check_hostname = ssl_check_hostname
-        self._create_producer()
+        self.producer = self._create_producer()
 
         logging.getLogger("kafka").setLevel(loglevel)
 
@@ -202,7 +207,7 @@ class KafkaProducer(EventChannel):
         import kafka
 
         if self.security_protocol == "SASL_PLAINTEXT":
-            self.producer = kafka.KafkaProducer(
+            return kafka.KafkaProducer(
                 bootstrap_servers=self.host,
                 value_serializer=lambda v: json.dumps(v).encode("utf-8"),
                 sasl_plain_username=self.sasl_username,
@@ -211,7 +216,7 @@ class KafkaProducer(EventChannel):
                 security_protocol=self.security_protocol,
             )
         elif self.security_protocol == "SSL":
-            self.producer = kafka.KafkaProducer(
+            return kafka.KafkaProducer(
                 bootstrap_servers=self.host,
                 value_serializer=lambda v: json.dumps(v).encode("utf-8"),
                 ssl_cafile=self.ssl_cafile,
@@ -221,10 +226,12 @@ class KafkaProducer(EventChannel):
                 security_protocol=self.security_protocol,
             )
         elif self.security_protocol == "PLAINTEXT":
-            self.producer = kafka.KafkaProducer(
+            return kafka.KafkaProducer(
                 bootstrap_servers=self.host,
                 value_serializer=lambda v: json.dumps(v).encode("utf-8")
             )
+        else:
+            return None
 
     def _publish(self, event):
         # self.producer.send(self.topic, event)
@@ -237,7 +244,11 @@ class KafkaProducer(EventChannel):
         self.producer.close()
 
     def is_connected(self):
-        return self.producer.bootstrap_connected()
+        producer = self._create_producer()
+        is_connected = producer.bootstrap_connected()
+        producer.close()
+        return is_connected
+
 
 class SQLProducer(EventChannel):
     """Save events into an SQL database.
@@ -293,3 +304,6 @@ class SQLProducer(EventChannel):
             )
         )
         self.session.commit()
+
+    def is_connected(self):
+        return True
\ No newline at end of file
