@@ -27,7 +27,6 @@ logger = logging.getLogger(__name__)
 
 class UserMessage(object):
     """Represents an incoming message.
-
      Includes the channel the responses should be sent to."""
 
     DEFAULT_SENDER_ID = "default"
@@ -45,7 +44,6 @@ class UserMessage(object):
             metadata: Optional[Dict] = None,
     ) -> None:
         """Creates a ``UserMessage`` object.
-
         Args:
             text: the message text content.
             output_channel: the output channel which should be used to send
@@ -84,7 +82,7 @@ class UserMessage(object):
 
 
 def register(
-        input_channels: List["InputChannel"], app: Sanic, route: Optional[Text]
+    input_channels: List["InputChannel"], app: Sanic, route: Optional[Text]
 ) -> None:
     async def handler(*args, **kwargs):
         await app.agent.handle_message(*args, **kwargs)
@@ -113,10 +111,9 @@ class InputChannel(object):
         return self.name()
 
     def blueprint(
-            self, on_new_message: Callable[[UserMessage], Awaitable[None]]
+        self, on_new_message: Callable[[UserMessage], Awaitable[None]]
     ) -> Blueprint:
         """Defines a Sanic blueprint.
-
         The blueprint will be attached to a running sanic server and handle
         incoming routes it registered for."""
         raise NotImplementedError("Component listener needs to provide blueprint.")
@@ -134,6 +131,18 @@ class InputChannel(object):
             )
         )
 
+    def get_output_channel(self) -> Optional["OutputChannel"]:
+        """Create ``OutputChannel`` based on information provided by the input channel.
+        Implementing this function is not required. If this function returns a valid
+        ``OutputChannel`` this can be used by Rasa to send bot responses to the user
+        without the user initiating an interaction.
+        Returns:
+            ``OutputChannel`` instance or ``None`` in case creating an output channel
+             only based on the information present in the ``InputChannel`` is not
+             possible.
+        """
+        pass
+
     async def startTracking(self, channelUserId, channel, sid):
         # make IDP request here and append guid to message
         host = environ["IDENTITY_PROVIDER_HOST"]
@@ -162,7 +171,6 @@ class InputChannel(object):
 
 class OutputChannel(object):
     """Output channel base class.
-
     Provides sane implementation of the send methods
     for text only output channels."""
 
@@ -173,7 +181,7 @@ class OutputChannel(object):
 
     async def send_response(self, recipient_id: Text, message: Dict[Text, Any]) -> None:
         """Send a message to the client."""
-        
+
         if message.get("quick_replies"):
             await self.send_quick_replies(
                 recipient_id,
@@ -207,7 +215,7 @@ class OutputChannel(object):
             await self.send_elements(recipient_id, message.pop("elements"), **message)
 
     async def send_text_message(
-            self, recipient_id: Text, text: Text, **kwargs: Any
+        self, recipient_id: Text, text: Text, **kwargs: Any
     ) -> None:
         """Send a message through this channel."""
 
@@ -216,12 +224,12 @@ class OutputChannel(object):
         )
 
     async def send_image_url(
-            self, recipient_id: Text, image: Text, **kwargs: Any
+        self, recipient_id: Text, image: Text, **kwargs: Any
     ) -> None:
         """Sends an image. Default will just post the url as a string."""
 
         await self.send_text_message(recipient_id, "Image: {}".format(image), **kwargs)
-
+    
     async def send_video_url(
             self, recipient_id: Text, video: Text, **kwargs: Any
     ) -> None:
@@ -230,7 +238,7 @@ class OutputChannel(object):
         await self.send_text_message(recipient_id, "Video: {}".format(video), **kwargs)
 
     async def send_attachment(
-            self, recipient_id: Text, attachment: Text, **kwargs: Any
+        self, recipient_id: Text, attachment: Text, **kwargs: Any
     ) -> None:
         """Sends an attachment. Default will just post as a string."""
 
@@ -239,14 +247,13 @@ class OutputChannel(object):
         )
 
     async def send_text_with_buttons(
-            self,
-            recipient_id: Text,
-            text: Text,
-            buttons: List[Dict[Text, Any]],
-            **kwargs: Any
+        self,
+        recipient_id: Text,
+        text: Text,
+        buttons: List[Dict[Text, Any]],
+        **kwargs: Any
     ) -> None:
         """Sends buttons to the output.
-
         Default implementation will just post the buttons as a string."""
 
         await self.send_text_message(recipient_id, text, **kwargs)
@@ -255,23 +262,21 @@ class OutputChannel(object):
             await self.send_text_message(recipient_id, button_msg, **kwargs)
 
     async def send_quick_replies(
-            self,
-            recipient_id: Text,
-            text: Text,
-            quick_replies: List[Dict[Text, Any]],
-            **kwargs: Any
+        self,
+        recipient_id: Text,
+        text: Text,
+        quick_replies: List[Dict[Text, Any]],
+        **kwargs: Any
     ) -> None:
         """Sends quick replies to the output.
-
         Default implementation will just send as buttons."""
 
         await self.send_text_with_buttons(recipient_id, text, quick_replies, **kwargs)
 
     async def send_elements(
-            self, recipient_id: Text, elements: Iterable[Dict[Text, Any]], **kwargs: Any
+        self, recipient_id: Text, elements: Iterable[Dict[Text, Any]], **kwargs: Any
     ) -> None:
         """Sends elements to the output.
-
         Default implementation will just post the elements as a string."""
 
         for element in elements:
@@ -279,14 +284,13 @@ class OutputChannel(object):
                 title=element.get("title", ""), subtitle=element.get("subtitle", "")
             )
             await self.send_text_with_buttons(
-                recipient_id, element_msg, element.get("buttons", [])
+                recipient_id, element_msg, element.get("buttons", [], **kwargs)
             )
 
     async def send_custom_json(
-            self, recipient_id: Text, json_message: Dict[Text, Any], **kwargs: Any
+        self, recipient_id: Text, json_message: Dict[Text, Any], **kwargs: Any
     ) -> None:
         """Sends json dict to the output channel.
-
         Default implementation will just post the json contents as a string."""
 
         await self.send_text_message(recipient_id, json.dumps(json_message), **kwargs)
@@ -294,7 +298,6 @@ class OutputChannel(object):
 
 class CollectingOutputChannel(OutputChannel):
     """Output channel that collects send messages in a list
-
     (doesn't send them anywhere, just collects them)."""
 
     def __init__(self):
@@ -306,7 +309,7 @@ class CollectingOutputChannel(OutputChannel):
 
     @staticmethod
     def _message(
-            recipient_id, text=None, image=None, video=None, buttons=None, attachment=None, custom=None
+        recipient_id, text=None, image=None, video=None, buttons=None, attachment=None, custom=None
     ):
         """Create a message object that will be stored."""
 
@@ -314,7 +317,6 @@ class CollectingOutputChannel(OutputChannel):
             "recipient_id": recipient_id,
             "text": text,
             "image": image,
-            "video": video,
             "buttons": buttons,
             "attachment": attachment,
             "custom": custom,
@@ -333,13 +335,13 @@ class CollectingOutputChannel(OutputChannel):
         self.messages.append(message)  # pytype: disable=bad-return-type
 
     async def send_text_message(
-            self, recipient_id: Text, text: Text, **kwargs: Any
+        self, recipient_id: Text, text: Text, **kwargs: Any
     ) -> None:
         for message_part in text.split("\n\n"):
             await self._persist_message(self._message(recipient_id, text=message_part))
 
     async def send_image_url(
-            self, recipient_id: Text, image: Text, **kwargs: Any
+        self, recipient_id: Text, image: Text, **kwargs: Any
     ) -> None:
         """Sends an image. Default will just post the url as a string."""
 
@@ -353,32 +355,31 @@ class CollectingOutputChannel(OutputChannel):
         await self._persist_message(self._message(recipient_id, video=video))
 
     async def send_attachment(
-            self, recipient_id: Text, attachment: Text, **kwargs: Any
+        self, recipient_id: Text, attachment: Text, **kwargs: Any
     ) -> None:
         """Sends an attachment. Default will just post as a string."""
 
         await self._persist_message(self._message(recipient_id, attachment=attachment))
 
     async def send_text_with_buttons(
-            self,
-            recipient_id: Text,
-            text: Text,
-            buttons: List[Dict[Text, Any]],
-            **kwargs: Any
+        self,
+        recipient_id: Text,
+        text: Text,
+        buttons: List[Dict[Text, Any]],
+        **kwargs: Any
     ) -> None:
         await self._persist_message(
             self._message(recipient_id, text=text, buttons=buttons)
         )
 
     async def send_custom_json(
-            self, recipient_id: Text, json_message: Dict[Text, Any], **kwargs: Any
+        self, recipient_id: Text, json_message: Dict[Text, Any], **kwargs: Any
     ) -> None:
         await self._persist_message(self._message(recipient_id, custom=json_message))
 
 
 class QueueOutputChannel(CollectingOutputChannel):
     """Output channel that collects send messages in a list
-
     (doesn't send them anywhere, just collects them)."""
 
     @classmethod
@@ -399,7 +400,6 @@ class QueueOutputChannel(CollectingOutputChannel):
 
 class RestInput(InputChannel):
     """A custom http input channel.
-
     This implementation is the basis for a custom implementation of a chat
     frontend. You can customize this to send messages to Rasa Core and
     retrieve responses from the agent."""
@@ -410,11 +410,11 @@ class RestInput(InputChannel):
 
     @staticmethod
     async def on_message_wrapper(
-            on_new_message: Callable[[UserMessage], Awaitable[None]],
-            text: Text,
-            queue: Queue,
-            sender_id: Text,
-            input_channel,
+        on_new_message: Callable[[UserMessage], Awaitable[None]],
+        text: Text,
+        queue: Queue,
+        sender_id: Text,
+        input_channel: Text,
     ) -> None:
         collector = QueueOutputChannel(queue)
 
@@ -434,11 +434,11 @@ class RestInput(InputChannel):
         return req.json.get("input_channel") or self.name()
 
     def stream_response(
-            self,
-            on_new_message: Callable[[UserMessage], Awaitable[None]],
-            text: Text,
-            sender_id: Text,
-            input_channel: Text,
+        self,
+        on_new_message: Callable[[UserMessage], Awaitable[None]],
+        text: Text,
+        sender_id: Text,
+        input_channel: Text,
     ) -> Callable[[Any], Awaitable[None]]:
         async def stream(resp: Any) -> None:
             q = Queue()
@@ -506,4 +506,4 @@ class RestInput(InputChannel):
                     )
                 return response.json(collector.messages)
 
-        return custom_webhook
+        return custom_webhook
\ No newline at end of file
