@@ -275,7 +275,10 @@ class MessageProcessor(object):
         if slot_values.strip():
             logger.debug("Current slot values: \n{}".format(slot_values))
 
-    def _is_nlu_threshold_passed(self, nlu_data):
+    def _is_nlu_threshold_passed(self, nlu_data, tracker):
+        if self.policy_ensemble is None or tracker.active_form:
+            return True
+
         form_fallback_policy = self.policy_ensemble.look_up_policy(FormFallbackPolicy)
         nlu_confidence = nlu_data.get("intent", {}).get("confidence", 0)
 
@@ -306,6 +309,26 @@ class MessageProcessor(object):
         )
         return parse_data
 
+    def create_metadata(
+            self, message: UserMessage, tracker: DialogueStateTracker
+    ) -> Dict:
+        requested_slot = tracker.get_slot("requested_slot")
+        metadata = {"type": "user_response"}
+
+        if tracker.active_form.get("name"):
+            metadata["active_form"] = tracker.active_form.get("name")
+
+        if requested_slot:
+            metadata["requested_slot"] = requested_slot
+
+            if requested_slot == "pass":
+                metadata["is_pii"] = True
+                metadata["type"] = "password"
+            elif requested_slot == "id":
+                metadata["type"] = "username"
+
+        return metadata
+
     async def _handle_message_with_tracker(
         self, message: UserMessage, tracker: DialogueStateTracker
     ) -> None:
@@ -315,7 +338,12 @@ class MessageProcessor(object):
         else:
             parse_data = await self._parse_message(message)
 
-        missed_intent = not self._is_nlu_threshold_passed(parse_data)
+        missed_intent = not self._is_nlu_threshold_passed(parse_data, tracker)
+
+        if message.metadata:
+            message.metadata.update(self.create_metadata(message, tracker))
+        else:
+            message.metadata = self.create_metadata(message, tracker)
 
         # don't ever directly mutate the tracker
         # - instead pass its events to log
@@ -335,6 +363,19 @@ class MessageProcessor(object):
             self.domain,
         )
 
+        if self._is_goodbye_msg_callback_received(tracker) and tracker.get_slot('outcome') != 'Transfer':
+            outcome = "Disconnected"
+            if tracker.get_latest_input_channel().startswith('OMNI_VOICE'):
+                outcome = "Hangup"
+
+            evt = {
+                "name": "CONVERSATION_END",
+                "message": outcome,
+                "timestamp": int(round(time.time() * 1000))
+            }
+            tracker.update(SlotSet("system_event", evt))
+            tracker.update(SlotSet("outcome", outcome))
+
         if parse_data["entities"]:
             self._log_slots(tracker)
 
