@@ -180,12 +180,8 @@ def serve_application(
     )
 
     async def clear_model_files(app: Sanic, _loop: Text) -> None:
-        from rasa.nlu.extractors.duckling_http_extractor import session
-
         if app.agent.model_directory:
             shutil.rmtree(app.agent.model_directory)
-        if session:
-            await session.close()
 
     app.register_listener(clear_model_files, "after_server_stop")
 
