@@ -120,18 +120,8 @@ class TrackerStore(object):
                 for evt in list(itertools.islice(evts, offset, len(evts))):
                     body = {"sender_id": tracker.sender_id}
                     body.update(evt.as_dict())
-                    is_pii = tracker.get_slot('is_pii')
                     body["message_id"] = tracker.get_slot("messageId")
 
-                    if body.get('event') == 'slot' and self.is_authenticate_state(tracker) and body.get('value') == 'pass':
-                        tracker.update(SlotSet('is_pii', True))
-                    elif is_pii and body.get('event') == 'user':
-                        body['text'] = '{authentication}'
-
-                    if body.get('event') == 'user' and tracker.current_state().get("active_form") and tracker.latest_message.intent.get('name') is None:
-                        body['parse_data']['intent']['name'] = 'Test'
-                        body['parse_data']['intent']['confidence'] = 1.0
-
                     if body.get('event') == 'bot':
                         body["prediction_error"] = tracker.get_slot('predictionError')
                         tracker.update(SlotSet('predictionError', False))
@@ -177,7 +167,7 @@ class TrackerStore(object):
         }
         return timeouts.get(channel)
 
-    async def ping(self):
+    async def test_conn(self):
         return "ok"
 
 
