@@ -162,7 +162,7 @@ class CRFEntityExtractor(EntityExtractor):
                 "for details".format(message.text)
             )
 
-    async def process(self, message: Message, **kwargs: Any) -> None:
+    def process(self, message: Message, **kwargs: Any) -> None:
 
         self._check_spacy_doc(message)
 
