@@ -1,10 +1,7 @@
-import asyncio
 import time
 
 import logging
 import os
-
-import aiohttp
 import requests
 from typing import Any, List, Optional, Text, Dict
 
@@ -14,7 +11,6 @@ from rasa.nlu.model import Metadata
 from rasa.nlu.training_data import Message
 
 logger = logging.getLogger(__name__)
-session = aiohttp.ClientSession()
 
 
 def extract_value(match):
@@ -108,7 +104,7 @@ class DucklingHTTPExtractor(EntityExtractor):
             "reftime": reference_time,
         }
 
-    async def _duckling_parse(self, text, reference_time):
+    def _duckling_parse(self, text, reference_time):
         """Sends the request to the duckling server and parses the result."""
 
         try:
@@ -116,21 +112,19 @@ class DucklingHTTPExtractor(EntityExtractor):
             headers = {
                 "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8"
             }
-
-            async with session.post(self._url() + "/parse", data=payload, headers=headers, timeout=3) as response:
-                if response.status == 200:
-                    return await response.json()
-                else:
-                    logger.error(
-                        "Failed to get a proper response from remote "
-                        "duckling. Status Code: {}. Response: {}"
-                        "".format(response.status, response.text)
-                    )
-                    return []
-        except (
-                asyncio.CancelledError,
-                asyncio.TimeoutError
-        ) as e:
+            response = requests.post(
+                self._url() + "/parse", data=payload, headers=headers
+            )
+            if response.status_code == 200:
+                return response.json()
+            else:
+                logger.error(
+                    "Failed to get a proper response from remote "
+                    "duckling. Status Code: {}. Response: {}"
+                    "".format(response.status_code, response.text)
+                )
+                return []
+        except requests.exceptions.ConnectionError as e:
             logger.error(
                 "Failed to connect to duckling http server. Make sure "
                 "the duckling server is running and the proper host "
@@ -158,11 +152,11 @@ class DucklingHTTPExtractor(EntityExtractor):
         # requires the reftime in miliseconds
         return int(time.time()) * 1000
 
-    async def process(self, message: Message, **kwargs: Any) -> None:
+    def process(self, message: Message, **kwargs: Any) -> None:
 
         if self._url() is not None:
             reference_time = self._reference_time_from_message(message)
-            matches = await self._duckling_parse(message.text, reference_time)
+            matches = self._duckling_parse(message.text, reference_time)
             all_extracted = convert_duckling_format_to_rasa(matches)
             dimensions = self.component_config["dimensions"]
             extracted = DucklingHTTPExtractor.filter_irrelevant_entities(
