@@ -34,7 +34,7 @@ class SpacyFeaturizer(Featurizer):
         for example in training_data.intent_examples:
             self._set_spacy_features(example)
 
-    async def process(self, message: Message, **kwargs: Any) -> None:
+    def process(self, message: Message, **kwargs: Any) -> None:
 
         self._set_spacy_features(message)
 
