@@ -351,7 +351,7 @@ class Interpreter(object):
         self.context = context if context is not None else {}
         self.model_metadata = model_metadata
 
-    async def parse(
+    def parse(
         self,
         text: Text,
         time: Optional[datetime.datetime] = None,
@@ -373,7 +373,7 @@ class Interpreter(object):
         message = Message(text, self.default_output_attributes(), time=time)
 
         for component in self.pipeline:
-            await component.process(message, **self.context)
+            component.process(message, **self.context)
 
         output = self.default_output_attributes()
         output.update(message.as_dict(only_output_properties=only_output_properties))
