@@ -31,7 +31,9 @@ from rasa.nlu.model import Interpreter, Trainer, TrainingData
 from rasa.nlu.components import Component
 from rasa.nlu.tokenizers import Token
 
+# import matplotlib
 logger = logging.getLogger(__name__)
+# matplotlib.use('TkAgg')
 
 PRETRAINED_EXTRACTORS = {"DucklingHTTPExtractor", "SpacyEntityExtractor"}
 
@@ -621,8 +623,7 @@ def get_eval_data(
     should_eval_entities = is_entity_extractor_present(interpreter)
 
     for example in tqdm(test_data.training_examples):
-        loop = asyncio.get_event_loop()
-        result = loop.run_until_complete(interpreter.parse(example.text, only_output_properties=False))
+        result = interpreter.parse(example.text, only_output_properties=False)
 
         if should_eval_intents:
             intent_prediction = result.get("intent", {}) or {}
