@@ -23,7 +23,7 @@ class SpacyTokenizer(Tokenizer, Component):
         for example in training_data.training_examples:
             example.set("tokens", self.tokenize(example.get("spacy_doc")))
 
-    async def process(self, message: Message, **kwargs: Any) -> None:
+    def process(self, message: Message, **kwargs: Any) -> None:
 
         message.set("tokens", self.tokenize(message.get("spacy_doc")))
 
