@@ -18,7 +18,6 @@ import rasa
 import rasa.utils.common
 import rasa.utils.endpoints
 import rasa.utils.io
-from config.jaeger_config import initialize_tracer
 from metrics.constants import CHAT_LATENCY
 from rasa.core.domain import InvalidDomain
 from rasa.utils.endpoints import EndpointConfig
@@ -331,8 +330,9 @@ def create_app(
     @app.listener('after_server_start')
     async def notify_server_started(app, loop):
         import aiohttp
-
-        initialize_tracer('hydra')
+        # from config.jaeger_config import initialize_tracer
+        #
+        # initialize_tracer('hydra')
         app.session = aiohttp.ClientSession()
 
     @app.listener('before_server_stop')
@@ -369,20 +369,15 @@ def create_app(
         timeout = 10
 
         try:
-            resp = None
-
             if endpoints.tracker_store:
                 resp = await asyncio.wait_for(app.agent.tracker_store.test_conn(), timeout=timeout)
-                # _broker = app.agent.tracker_store.event_broker
-                # if not _broker.is_connected():
-                #     raise ErrorResponse(500, "ServerError", "Kafka clusters are not available.")
 
-            if resp:
-                logger.info({"event": "HEALTH_CHECK", "message": "Dialog Manager is up and running."})
-                return response.json({"status": "ok"})
-            else:
-                logger.error({"event": "HEALTH_CHECK", "message": "Dialog Manager is down."})
-                raise ErrorResponse(500, "ServerError", "Dialog Manager is not alive")
+                if not resp:
+                    logger.error({"event": "HEALTH_CHECK", "message": "Dialog Manager is down."})
+                    raise ErrorResponse(500, "ServerError", "Dialog Manager is not alive")
+
+            logger.info({"event": "HEALTH_CHECK", "message": "Dialog Manager is up and running."})
+            return response.json({"status": "ok"})
         except ErrorResponse as ex:
             logger.error({"event": "HEALTH_CHECK", "message": ex})
             raise ex
@@ -396,6 +391,7 @@ def create_app(
         """Check if the server is running and responds with the version."""
         timeout = 10
         action_resp, duckling_resp = None, None
+        _broker = app.agent.tracker_store.event_broker
 
         try:
             if endpoints.action:
@@ -405,6 +401,9 @@ def create_app(
             if endpoints.duckling:
                 duckling_resp = await app.session.get(endpoints.duckling.url, timeout=timeout)
 
+            if _broker and not _broker.is_connected():
+                raise ErrorResponse(500, "ServerError", "Event broker is not available.")
+
             if not app.agent.is_ready(allow_nlu_only=True):
                 raise ErrorResponse(500, "AgentError", "Agent is not ready yet.")
             elif action_resp and action_resp.status != 200:
@@ -927,7 +926,6 @@ def create_app(
                 _broker = app.agent.tracker_store.event_broker
                 if _broker:
                     event = {
-                        'sender_id': 'NA',
                         'event': 'nlu',
                         'timestamp': time.time(),
                         'parse_data': response_data,
@@ -984,27 +982,6 @@ def create_app(
                 )
             response_data = predList
 
-            # Publish the payload through the event broker.
-            try:
-                _broker = app.agent.tracker_store.event_broker
-                if _broker:
-                    event = {
-                        'sender_id': 'NA',
-                        'event': 'nlu',
-                        'timestamp': time.time(),
-                        'parse_data': response_data,
-                        'text': response_data["text"],
-                        'channel': 'rest'
-                    }
-                    logger.info(f"NLU parse: {event}")
-                    _broker.publish(event)
-                else:
-                    logger.warning("No event broker is configured, skipping events publish.")
-            except Exception as e:
-                logger.debug(traceback.format_exc())
-                raise ErrorResponse(
-                    500, "EventBrokerError", "An unexpected error occurred. Error: {}".format(e)
-                )
 
             return response.json(response_data)
 
